@@ -17,7 +17,7 @@ https://www.themoviedb.org/documentation/api/status-codes
 """
 
 __title__ = 'tmdbsimple'
-__version__ = '2.5.1'
+__version__ = '2.6.0'
 __author__ = 'Celia Oakley'
 __copyright__ = 'Copyright (c) 2013-2020 Celia Oakley'
 __license__ = 'GPLv3'
@@ -27,24 +27,24 @@ import os
 from .account import Account, Authentication, GuestSessions, Lists
 from .base import APIKeyError
 from .changes import Changes
-from .configuration import Configuration, Certifications, Timezones
+from .configuration import Configuration, Certifications
 from .discover import Discover
 from .find import Find, Trending
 from .genres import Genres
 from .movies import Movies, Collections, Companies, Keywords, Reviews
-from .people import People, Credits, Jobs
+from .people import People, Credits
 from .search import Search
 from .tv import TV, TV_Seasons, TV_Episodes, TV_Episode_Groups, TV_Changes, Networks
 
 __all__ = ['Account', 'Authentication', 'GuestSessions', 'Lists',
            'APIKeyError',
            'Changes',
-           'Configuration', 'Certifications', 'Timezones',
+           'Configuration', 'Certifications',
            'Discover',
            'Find', 'Trending',
            'Genres',
            'Movies', 'Collections', 'Companies', 'Keywords', 'Reviews',
-           'People', 'Credits', 'Jobs',
+           'People', 'Credits'
            'Search',
            'TV', 'TV_Seasons', 'TV_Episodes', 'TV_Episode_Groups', 'TV_Changes', 'Networks'
            ]
