@@ -45,7 +45,7 @@ class Account(TMDB):
         """
         Get your account details.
 
-        Call this method first, before calling other Account methods.
+        Args:
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -60,11 +60,12 @@ class Account(TMDB):
 
     def lists(self, **kwargs):
         """
-        Get all of the lists created by an account. Will include private lists if you are the owner.
+        Get all of the lists created by an account. Will include private lists
+        if you are the owner.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
             language: (optional) ISO 639-1 code.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -81,9 +82,9 @@ class Account(TMDB):
         Get the list of your favorite movies.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
-            sort_by: (optional) 'created_at.asc' | 'created_at.desc'
             language: (optional) ISO 639-1 code.
+            sort_by: (optional) 'created_at.asc' | 'created_at.desc'
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -100,9 +101,9 @@ class Account(TMDB):
         Get the list of your favorite TV shows.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
-            sort_by: (optional) 'created_at.asc' | 'created_at.desc'
             language: (optional) ISO 639-1 code.
+            sort_by: (optional) 'created_at.asc' | 'created_at.desc'
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -144,9 +145,9 @@ class Account(TMDB):
         Get a list of all the movies you have rated.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
+            language: (optional) ISO 639-1 value.
             sort_by: (optional) 'created_at.asc' | 'created_at.desc'
-            language: (optional) ISO 639-1 code.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -163,9 +164,9 @@ class Account(TMDB):
         Get a list of all the TV shows you have rated.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
+            language: (optional) ISO 639-1 value.
             sort_by: (optional) 'created_at.asc' | 'created_at.desc'
-            language: (optional) ISO 639-1 code.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -182,9 +183,9 @@ class Account(TMDB):
         Get a list of all the TV episodes you have rated.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
+            language: (optional) ISO 639-1 value.
             sort_by: (optional) 'created_at.asc' | 'created_at.desc'
-            language: (optional) ISO 639-1 code.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -201,9 +202,9 @@ class Account(TMDB):
         Get a list of all the movies you have added to your watchlist.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
+            language: (optional) ISO 639-1 value.
             sort_by: (optional) 'created_at.asc' | 'created_at.desc'
-            language: (optional) ISO 639-1 code.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -220,9 +221,9 @@ class Account(TMDB):
         Get a list of all the TV shows you have added to your watchlist.
 
         Args:
-            page: (optional) Minimum 1, maximum 1000.
+            language: (optional) ISO 639-1 value.
             sort_by: (optional) 'created_at.asc' | 'created_at.desc'
-            language: (optional) ISO 639-1 code.
+            page: (optional) Minimum 1, maximum 1000, default 1.
 
         Returns:
             A dict respresentation of the JSON returned from the API.
@@ -273,6 +274,7 @@ class Authentication(TMDB):
         'token_new': '/token/new',
         'session_new': '/session/new',
         'token_validate_with_login': '/token/validate_with_login',
+        'session_delete': '/session',
     }
 
     def guest_session_new(self, **kwargs):
@@ -292,6 +294,8 @@ class Authentication(TMDB):
         If a guest session is not used for the first time within 24 hours,
         it will be automatically deleted.
 
+        Args:
+
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
@@ -307,6 +311,8 @@ class Authentication(TMDB):
         user login. More details about how this works can be found here
         (https://developers.themoviedb.org/3/authentication/how-do-i-generate-a-session-id).
 
+        Args:
+
         Returns:
             A dict respresentation of the JSON returned from the API.
         """
@@ -366,6 +372,26 @@ class Authentication(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def session_delete(self, **kwargs):
+        """
+        If you would like to delete (or "logout") from a session, call this
+        method with a valid session ID.
+
+        Args:
+
+        Returns:
+            A dict respresentation of the JSON returned from the API.
+        """
+        path = self._get_path('session_delete')
+
+        payload = {
+            'session_id': kwargs.pop('session_id', None),
+        }
+
+        response = self._DELETE(path, kwargs, payload)
+        self._set_attrs_to_values(response)
+        return response
+
 
 class GuestSessions(TMDB):
     """
@@ -453,6 +479,7 @@ class Lists(TMDB):
         'add_item': '/{id}/add_item',
         'remove_item': '/{id}/remove_item',
         'list_clear': '/{id}/clear',
+        'list_delete': '/{id}',
     }
 
     def __init__(self, id=0, session_id=0):
@@ -508,12 +535,12 @@ class Lists(TMDB):
         payload = {
             'name': kwargs.pop('name', None),
             'description': kwargs.pop('description', None),
+            'language': kwargs.pop('language', None),
         }
-        if 'language' in kwargs:
-            payload['language'] = kwargs['language']
 
         response = self._POST(path, kwargs, payload)
         self._set_attrs_to_values(response)
+        self.id = self.list_id
         return response
 
     def add_item(self, **kwargs):
@@ -576,3 +603,19 @@ class Lists(TMDB):
         response = self._POST(path, kwargs, payload)
         self._set_attrs_to_values(response)
         return response
+
+    def list_delete(self, **kwargs):
+        """
+        Delete a list.
+
+        Args:
+
+        Returns:
+            A dict respresentation of the JSON returned from the API.
+        """
+        path = self._get_id_path('list_delete')
+        kwargs.update({'session_id': self.session_id})
+
+        response = self._DELETE(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
