@@ -13,6 +13,7 @@ Created by Celia Oakley on 2013-10-31.
 
 from .base import TMDB
 
+
 class Find(TMDB):
     """
     Find functionality.
@@ -23,6 +24,7 @@ class Find(TMDB):
     URLS = {
         'info': '/{id}',
     }
+
     def __init__(self, id=0):
         super(Find, self).__init__()
         self.id = id
@@ -63,6 +65,7 @@ class Trending(TMDB):
     URLS = {
         'info': '/{media_type}/{time_window}',
     }
+
     def __init__(self, media_type='all', time_window='day'):
         super(Trending, self).__init__()
         self.media_type = media_type
@@ -72,10 +75,12 @@ class Trending(TMDB):
         """
         Get the daily or weekly trending items. The daily trending list tracks
         items over the period of a day while items have a 24 hour half life.
-        The weekly list tracks items over a 7 day period, with a 7 day half life.
+        The weekly list tracks items over a 7 day period, with a 7 day half
+        life.
 
         Valid Media Types
-            'all': Include all movies, TV shows and people in the results as a global trending list.
+            'all': Include all movies, TV shows and people in the results as a
+                   global trending list.
             'movie': Show the trending movies in the results.
             'tv': Show the trending TV shows in the results.
             'people': Show the trending people in the results.
