@@ -38,12 +38,13 @@ class Movies(TMDB):
         'similar_movies': '/{id}/similar_movies',
         'reviews': '/{id}/reviews',
         'lists': '/{id}/lists',
+        'rating': '/{id}/rating',
+        'rating_delete': '/{id}/rating',
         'latest': '/latest',
         'now_playing': '/now_playing',
         'popular': '/popular',
         'top_rated': '/top_rated',
         'upcoming': '/upcoming',
-        'rating': '/{id}/rating',       # backward compatability
         'releases': '/{id}/releases',   # backward compatability
     }
 
@@ -374,7 +375,7 @@ class Movies(TMDB):
         Returns:
             A dict representation of the JSON returned from the API.
         """
-        path = self._get_id_path('rating')
+        path = self._get_id_path('rating_delete')
 
         payload = {
             'value': kwargs.pop('value', None),
@@ -521,7 +522,6 @@ class Collections(TMDB):
 
         Args:
             language: (optional) ISO 639-1 code.
-            append_to_response: (optional) Comma separated, any movie method.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -538,9 +538,6 @@ class Collections(TMDB):
 
         Args:
             language: (optional) ISO 639-1 code.
-            append_to_response: (optional) Comma separated, any movie method.
-            include_image_language: (optional) Comma separated, a valid
-            ISO 69-1.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -557,7 +554,6 @@ class Collections(TMDB):
 
         Args:
             language: (optional) ISO 639-1 code.
-            append_to_response: (optional) Comma separated, any movie method.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -592,7 +588,6 @@ class Companies(TMDB):
         Get a companies details by id.
 
         Args:
-            append_to_response: (optional) Comma separated, any movie method.
 
         Returns:
             A dict representation of the JSON returned from the API.
@@ -649,9 +644,8 @@ class Companies(TMDB):
         Get the list of movies associated with a particular company.
 
         Args:
-            page: (optional) Minimum value of 1.  Expected value is an integer.
             language: (optional) ISO 639-1 code.
-            append_to_response: (optional) Comma separated, any movie method.
+            page: (optional) Minimum value of 1.  Expected value is an integer.
 
         Returns:
             A dict representation of the JSON returned from the API.
